/* ========================================
 *
 * Copyright YOUR COMPANY, THE YEAR
 * All Rights Reserved
 * UNPUBLISHED, LICENSED SOFTWARE.
 *
 * CONFIDENTIAL AND PROPRIETARY INFORMATION
 * WHICH IS THE PROPERTY OF your company.
 *
 * ========================================
*/
#include "project.h"
#include "main.h"
#include <stdio.h> 
uint8 testMode;

void SysInit(void); 			/* Initializes the components and displays text on LCD. */
void UpdateLCD(void); 			/* Updates the LCD text. */
void SleepComponents(void);		/* Shuts down components that are not used in any low-power mode demo. */
void GoToLowPower(void); 		/* Prepares for the selected low-power mode, enters the mode, and restores after wakeup. */
void WakeComponents(void);		/* Wakes components that were slept in the SleepComponents() function. */
void UpdateTime(void);			/* Updates the time on the LCD when demonstrating sleep+RTC mode. */
void ButtonDebounce(void);	

int main()
{
	SysInit();
    for(;;)
    {

		if (Button_ClearInterrupt() != 0) /* If the button was pressed... */
		{
			ButtonDebounce();
			GoToLowPower(); 			/* Launch low-power routine. */
		}
    }
}

void SysInit(void)
{
    // START - Turn off stimulator board power supplies
        HIGH_VOLT_ON_Write(POWER_OFF);// turn off HIGH Volts SSR
        BAT_POWER_ON_Write(SET_RELAY_OFF);  // Turn off latch control to set battery relays in ON mode  this should be off allready
        BAT_POWER_OFF_Write(RESET_RELAY_ON); // Turn on latch control to reset battery relays in OFF mode  *this turns off low volts
        CyDelay(TEN_ms);  // Delay 10 ms for relays to settle for LOW POWER
        BAT_POWER_OFF_Write(RESET_RELAY_OFF); // Turn off latch control to reset battery relays in OFF mode
        FAN_ON_Write(POWER_OFF); //Turn OFF the fan SSR
        MAIN_ON_Write(POWER_OFF); // turn off digital board power SSR
        CyDelay(TEN_ms);  // let digital stimulator board power down
        
        
        
        // put PSOC in control of LCD
        LCD_POWER_SetDriveMode(LCD_POWER_DM_STRONG); 
        LCD_LCDPort_SetDriveMode(CY_PINS_DM_STRONG);
        LCD_DIR_Write(POWER_ON);
        LCD_POWER_Write(POWER_ON);
        CyDelay(2u);  // delay a few ms for ssr to set
        LCD_Start();
        
        /* Start front panel LED logic. */
        FP_LED1_SetDriveMode(FP_LED1_DM_STRONG);
        FP_LED2_SetDriveMode(FP_LED2_DM_ALG_HIZ);
        FP_LED1_Write(LED_OFF);
    //END - Stimulator board power settings

	/* Initalize variables. */
	testMode = HIBERNATE;

	CyGlobalIntEnable;
	
	/* Set 32kHz xtal to lowest power in Sleep and Hibernate. */
	CyXTAL_32KHZ_SetPowerMode(CY_X32_LOWPOWER_MODE);

	/* Start pulse LED logic. */
	PWM_1_Start();
	PWM_2_Start();
	
	/* Start the LCD and display initial text. */
   
	LCD_Start();
	LCD_PrintString("PSoC 5 Low-Power");
	UpdateLCD();
    LED_S_Write(LED_ON);
    CyDelay(1900u);
    Button_ClearInterrupt();
}

void GoToLowPower(void)
{
	switch(testMode)
	{

		case SLEEPPICU : /* 0x21 - Sleep - PICU */
		{
			/* Display mode. */
			LCD_Position(1,0);
			LCD_PrintString("Sleep-PICU      ");
            LED_S_Write(LED_OFF);
			/* Start the button interrupt. */
			isr_ButtonPress_Start();
			/* Prepare for Sleep and enter it. */
			SleepComponents();
			CyPmSaveClocks();
			CyPmSleep(PM_SLEEP_TIME_NONE, PM_SLEEP_SRC_PICU);
			/* The PSoC wakes up here. Clear wakeup interrupts. */
            LED_S_Write(LED_ON);
			CyPmRestoreClocks();
			WakeComponents();
			/* Stop the button interrupt. */
			isr_ButtonPress_Stop();
			Button_ClearInterrupt();
			break;
		}


		case HIBERNATE : /* 0x41 - Hibernate - PICU */
		{
			/* Display mode and set LCD pins for low-power. */
			LCD_Position(1,0);
			LCD_PrintString("Hibernate       ");
            LED_S_Write(LED_OFF);
			/* Start the button interrupt. */
			isr_ButtonPress_Start();
			SleepComponents();
            
            LED_S_Write(LED_OFF);
            CyDelay(1000u);
            LED_S_Write(LED_ON);  //blink the LED so I know where I am in the code
            CyDelay(1000u);
            LED_S_Write(LED_OFF);
            CyDelay(1000u);
            LED_S_Write(LED_ON);
            CyDelay(1000u);
             LED_S_Write(LED_OFF);
            
			/* Save clocks and enter low power. */
			CyPmSaveClocks();
			CyPmHibernate();
 
            /* The PSoC wakes up here. Restore everything and clear PICU interrupt. */
			CyPmRestoreClocks();
            
            LED_S_Write(LED_ON); //Status LEDs so I know where I am in the code
            CyDelay(1000u);
            LED_S_Write(LED_OFF);
            CyDelay(1000u);
            LED_S_Write(LED_ON);
            
			WakeComponents();
			/* Stop the button interrupt. */
			isr_ButtonPress_Stop();
			Button_ClearInterrupt();
            
			break;
		}

		default : /* Mode not defined. */
		{
			/* Display an error message. */
			LCD_Position(1,0);
			LCD_PrintString("Undefined Mode  ");
			CyDelay(1500);
			break;
		}
	}
	
	/* Indicate wakeup. */
	UpdateLCD();
	ButtonDebounce();
}


void ButtonDebounce(void)
{
	CyDelay(250);
	Button_ClearInterrupt();
}

void UpdateLCD(void)
{
	/* Initalize line 2 for mode display. */
	LCD_Position(1,0);
	LCD_PrintString("TestMode:       ");
	/* Display the power mode range that is selected by testMode. */
	LCD_Position(1,10);
	/* Print testMode value to aid user. */
	LCD_PrintInt8(testMode);
    CyDelay(1900u);
}

void WakeComponents(void)
{
    FP_LED1_SetDriveMode(FP_LED1_DM_STRONG);
    PWM_1_Wakeup();
    PWM_2_Wakeup();
    //Turn on LCD
    LCD_POWER_SetDriveMode(LCD_POWER_DM_STRONG); 
    LCD_LCDPort_SetDriveMode(CY_PINS_DM_STRONG);
    LCD_DIR_Write(POWER_ON);
    LCD_POWER_Write(POWER_ON);

}
void SleepComponents(void)
{
    // Turn off LCD
    LCD_POWER_Write(POWER_OFF);
    LCD_DIR_Write(POWER_OFF);
    LCD_POWER_SetDriveMode(LCD_POWER_DM_ALG_HIZ); 
    LCD_LCDPort_SetDriveMode(CY_PINS_DM_ALG_HIZ);

	/* Stop PWMs and set Pulse pin for low-power. */
	PWM_1_Sleep();
	PWM_2_Sleep();
    FP_LED1_SetDriveMode(FP_LED1_DM_ALG_HIZ);
    

}

/* [] END OF FILE */